@@ -46,8 +46,19 @@ drop_labels_helper <- function(x, drop.na) {
     attr(x, "labels") <- NULL
   } else {
     labs <- names(tidy.labels)
+
+    # check if all label-values are numeric, and if so, convert to numeric
+    if (is.num.chr(labs)) labs <- as.numeric(labs)
+
+    # set back labels attribute
     names(labs) <- tidy.labels
     attr(x, "labels") <- labs
+
+    # if labels, e.g. due to taggend NA, are no longer of same
+    # type as labelled vector, remove labelled class attribute -
+    # else, haven will throw errors
+    if (inherits(x, "labelled") && typeof(x) != typeof(labs))
+      x <- unclass(x)
   }
 
   x
